@@ -1,26 +1,22 @@
 package Lingua::Translit::Tables;
 
-
 #
 # Copyright (C) 2007-2008 ...
 #   Alex Linke <alinke@lingua-systems.com>
 #   Rona Linke <rlinke@lingua-systems.com>
-# Copyright (C) 2009-2011 Lingua-Systems Software GmbH
+# Copyright (C) 2009-2014 Lingua-Systems Software GmbH
 #
 
-
 use strict;
 use warnings;
+use utf8;
 
 require 5.008;
 
-
-our $VERSION = '0.09';
-
+our $VERSION = '0.10';
 
 use Carp;
 
-
 =pod
 
 =head1 NAME
@@ -75,42 +71,58 @@ Import translit_list_supported(). (Convenience tag)
 
 =cut
 
-
 require Exporter;
 
-our @ISA        =   qw/Exporter/;
-our @EXPORT     =   qw//;           # Export nothing by default
-our @EXPORT_OK  =   qw/translit_supported translit_reverse_supported
-                       translit_list_supported/;
+our @ISA    = qw/Exporter/;
+our @EXPORT = qw//;           # Export nothing by default
+our @EXPORT_OK = qw/translit_supported translit_reverse_supported
+  translit_list_supported/;
 
 our %EXPORT_TAGS = (
-    checks  => [qw/translit_supported translit_reverse_supported/],
-    list    => [qw/translit_list_supported/],
-    all     => [@EXPORT_OK]
+    checks => [qw/translit_supported translit_reverse_supported/],
+    list   => [qw/translit_list_supported/],
+    all    => [@EXPORT_OK]
 );
 
-
-# For convenience, the tables are initialized at the bottom of this file
+# For convenience, the tables are initialized at the bottom of this file.
 our %tables;
 
-
-# used internally to retrieve a reference to a single transliteration table
-sub _get_table_reference
-{
+# Used internally to retrieve a reference to a single transliteration table.
+sub _get_table_reference {
     my $name = shift();
 
     return unless $name;
 
     $name = _get_table_id($name);
 
-    foreach my $table (keys %tables)
-    {
-        return $tables{$table} if ($table =~ /^$name$/i);
+    foreach my $table ( keys %tables ) {
+        return _handle_perl_unicode_bug( $tables{$table} )
+          if $table =~ /^$name$/i;
     }
 
     return;
 }
 
+# Handle the "Unicode Bug" affecting code points in the Latin-1 block.
+#
+# Have a look at perlunicode (section "The 'Unicode Bug'") for details.
+sub _handle_perl_unicode_bug {
+    my $tbl = shift();
+
+    foreach my $rule ( @{ $tbl->{rules} } ) {
+        utf8::upgrade( $rule->{from} );
+        utf8::upgrade( $rule->{to} );
+
+        if ( defined( $rule->{context} ) ) {
+            utf8::upgrade( $rule->{context}->{before} )
+              if defined $rule->{context}->{before};
+            utf8::upgrade( $rule->{context}->{after} )
+              if defined $rule->{context}->{after};
+        }
+    }
+
+    return $tbl;
+}
 
 =head1 ROUTINES
 
@@ -120,12 +132,10 @@ Returns true (1), iff I<translit_name> is supported. False (0) otherwise.
 
 =cut
 
-sub translit_supported
-{
-    return (_get_table_reference(_get_table_id($_[0])) ? 1 : 0);
+sub translit_supported {
+    return ( _get_table_reference( _get_table_id( $_[0] ) ) ? 1 : 0 );
 }
 
-
 =head2 translit_reverse_supported(I<translit_name>)
 
 Returns true (1), iff I<translit_name> is supported and allows reverse
@@ -133,16 +143,14 @@ transliteration. False (0) otherwise.
 
 =cut
 
-sub translit_reverse_supported
-{
-    my $table = _get_table_reference(_get_table_id($_[0]));
+sub translit_reverse_supported {
+    my $table = _get_table_reference( _get_table_id( $_[0] ) );
 
     croak("Failed to retrieve table for $_[0].") unless ($table);
 
-    return (($table->{reverse} =~ /^true$/) ? 1 : 0);
+    return ( ( $table->{reverse} =~ /^true$/ ) ? 1 : 0 );
 }
 
-
 =head2 B<translit_list_supported()>
 
 Prints a list of all supported transliterations to STDOUT, providing the
@@ -156,18 +164,15 @@ The same information is provided in this document as well:
 
 =cut
 
-sub translit_list_supported
-{
-    foreach my $table (sort keys %tables)
-    {
+sub translit_list_supported {
+    foreach my $table ( sort keys %tables ) {
         my $t = $tables{$table};
         print "$t->{name}, ",
-            ($t->{reverse} eq "false" ? "not " : ""),
-            "reversible, $t->{desc}\n";
+          ( $t->{reverse} eq "false" ? "not " : "" ),
+          "reversible, $t->{desc}\n";
     }
 }
 
-
 =head1 SUPPORTED TRANSLITERATIONS
 
 =over 4
@@ -218,10 +223,6 @@ I<Common SLK>, not reversible, Slovak without diacritics
 
 I<Common SLV>, not reversible, Slovenian without diacritics
 
-=item Mongolian
-
-I<Common Classical MON>, reversible, Classical Mongolian to Latin
-
 =back
 
 =head1 ADDING NEW TRANSLITERATIONS
@@ -230,7 +231,7 @@ In case you want to add your own transliteration tables to
 L<Lingua::Translit>, have a look at the developer manual included in the
 distribution.
 An online version is available at
-L<http://www.lingua-systems.com/downloads/Lingua-Translit/>.
+L<http://www.lingua-systems.com/translit/downloads/>.
 
 A template of a transliteration table is provided as well
 (F<xml/template.xml>) so you can easily start developing.
@@ -246,7 +247,7 @@ Please report bugs to perl@lingua-systems.com.
 
 L<Lingua::Translit>
 
-L<http://www.lingua-systems.com/transliteration/Lingua-Translit-Perl-module/>
+L<http://www.lingua-systems.com/translit/>
 
 
 =head1 CREDITS
@@ -254,9 +255,6 @@ L<http://www.lingua-systems.com/transliteration/Lingua-Translit-Perl-module/>
 Thanks to Dr. Daniel Eiwen, Romanisches Seminar, Universitaet Koeln for his
 help on Romanian transliteration.
 
-Thanks to Bayanzul Lodoysamba <baynaa@users.sourceforge.net> for contributing
-the "Common Classical Mongolian" transliteration table.
-
 Thanks to Dmitry Smal and Rusar Publishing for contributing the "ALA-LC RUS"
 transliteration table.
 
@@ -270,7 +268,7 @@ Rona Linke <rlinke@lingua-systems.com>
 
 Copyright (C) 2007-2008 Alex Linke and Rona Linke
 
-Copyright (C) 2009-2011 Lingua-Systems Software GmbH
+Copyright (C) 2009-2014 Lingua-Systems Software GmbH
 
 This module is free software. It may be used, redistributed
 and/or modified under the terms of either the GPL v2 or the
@@ -278,11 +276,9 @@ Artistic license.
 
 =cut
 
-
 # Get a table's identifier (based on the table's name)
 #   i.e "Common DEU" -> "common_deu"
-sub _get_table_id
-{
+sub _get_table_id {
     my $name = shift();
 
     return "" unless $name;
@@ -292,13 +288,10 @@ sub _get_table_id
     return lc($name);
 }
 
-
 # For convenience, the next line is automatically substituted with the set
 # of transliteration tables at build time.
-%tables; # PLACEHOLDER
-
+%tables;    # PLACEHOLDER
 
 1;
 
-
-# vim: sts=4 sw=4 ai et
+# vim: sts=4 sw=4 ts=4 ai et
